# Features API

Peak detection, band integration, ratios, and fingerprint similarity.

::: foodspec.features.peaks

::: foodspec.features.bands

::: foodspec.features.ratios

::: foodspec.features.fingerprint
